@@ -1,4 +1,4 @@
-/*$Id: config.h,v 1.101 2001/08/27 08:43:57 guenther Exp $*/
+/*$Id$*/
 
 /*#define sMAILBOX_SEPARATOR	"\1\1\1\1\n"	/* sTART- and eNDing separ.  */
 /*#define eMAILBOX_SEPARATOR	"\1\1\1\1\n"	/* uncomment (one or both)
@@ -33,8 +33,8 @@
  * override those settings you should uncomment and possibly change the
  * DEFSPATH and DEFPATH defines below
  */
-/*#define DEFSPATH	"PATH=/bin:/usr/bin"			/* */
-/*#define DEFPATH	"PATH=$HOME/bin:/bin:/usr/bin"		/* */
+/*#define DEFSPATH "PATH=/usr/local/bin:/bin:/usr/bin"			/* */
+/*#define DEFPATH  "PATH=$HOME/bin:/usr/local/bin:/bin:/usr/bin"	/* */
 
 /* every environment variable appearing in PRESTENV will be set or wiped
  * out of the environment (variables without an '=' sign will be thrown
@@ -126,6 +126,11 @@
 	called with the -m option, without variable assignments on the command
 	line). */
 
+#define CONFRC	"/etc/procmail.conf"	/* optional global procmail
+					   configuration file.  It is processed
+	after all variable except ORGMAIL are preset.  Filtering and delivering
+	actions will not be processed in this rcfile. */
+
 /*#define console	"/dev/console"	/* uncomment if you want procmail to
 					   use the console (or any other
 	terminal or file) to print any error messages that could not be dumped
@@ -137,6 +142,8 @@
  * Only edit below this line if you *think* you know what you are doing *
  ************************************************************************/
 
+#define DEFAULTdotlock	1             /* set to 0 to default to kernel locks */
+#define SANEvarmail	0      /* set to 1 if /var/mail has sane permissions */
 #define ROOT_uid	0
 #define LDENV		{"LD_","_RLD","LIBPATH=","ELF_LD_","AOUT_LD_",0}
 
@@ -258,7 +265,7 @@ MMGR)\
 \n   Or: procmail [-toY] [-f fromwhom] [-a argument] ... -d recipient ...\
 \n\
    Or: procmail [-ptY] [-f fromwhom] -m [parameter=value] ... rcfile [arg] ...\
-\n   Or: procmail [-toY] [-a argument] ... -z\
+\n   Or: procmail [-toY] [-a argument] ... -z [delim]\
 \n"
 #define PM_HELP		\
  "\t-v\t\tdisplay the version number and exit\
