@@ -8,9 +8,10 @@
  ************************************************************************/
 #ifdef RCS
 static /*const*/char rcsid[]=
- "$Id: foldinfo.c,v 1.11 2001/08/04 07:07:42 guenther Exp $";
+ "$Id$";
 #endif
 #include "procmail.h"
+#include "acommon.h"
 #include "misc.h"
 #include "lastdirsep.h"
 #include "robust.h"
@@ -167,9 +168,8 @@ ret:
   return type;
 }
 
-			     /* lifted out of main() to reduce main()'s size */
-int screenmailbox(chp,egid,Deliverymode)
- char*chp;const gid_t egid;const int Deliverymode;
+int screenmailbox(chp,egid,doautoforward)
+ char*chp;const gid_t egid;const int doautoforward;
 { char ch;struct stat stbuf;int basetype,type;
   /*
    *	  do we need sgidness to access the mail-spool directory/files?
@@ -202,7 +202,9 @@ int screenmailbox(chp,egid,Deliverymode)
 keepgid:			   /* keep the gid from the parent directory */
 	if((sgid=stbuf.st_gid)!=egid&&		  /* we were started nosgid, */
 	 setgid(sgid))				     /* but we might need it */
-	   checkroot('g',(unsigned long)sgid);
+	 { checkroot('g',(unsigned long)sgid);
+	   sgid=egid;
+	 }
    }
   else				/* panic, mail-spool directory not available */
    { setids();mkdir(buf,NORMdirperm);	     /* try creating the last member */
@@ -260,7 +262,7 @@ keepgid:			   /* keep the gid from the parent directory */
 	   if(lstat(buf,&stbuf))
 	      goto nobox;
 	 }					/* SysV type autoforwarding? */
-	if(Deliverymode&&(stbuf.st_mode&S_ISUID||
+	if(doautoforward&&(stbuf.st_mode&S_ISUID||
 	 !S_ISDIR(stbuf.st_mode)&&stbuf.st_mode&S_ISGID))
 	 { nlog("Autoforwarding mailbox found\n");
 	   exit(EX_NOUSER);
