@@ -10,7 +10,11 @@
 
 #define ft_lock(type)	   ((type)>ft_MAILDIR)		   /* kernel lock fd */
 #define ft_atime(type)	   ((type)==ft_FILE)	      /* force atime < mtime */
+#if DEFAULTdotlock
 #define ft_dotlock(type)   ((type)==ft_FILE)		 /* dotlock $DEFAULT */
+#else
+#define ft_dotlock(type)   ((type)>ft_MAILDIR)	     /* kernel lock $DEFAULT */
+#endif
 #define ft_delim(type)	   ((type)==ft_FILE)		   /* add MMDF delim */
 #define ft_checkcloser(type) ((type)>ft_MH)
 #define ft_forceblank(type) ((type)!=ft_MAILDIR)  /* force blank line at end */
@@ -18,7 +22,7 @@
 int
  foldertype Q((int type,int forcedir,mode_t*const modep,
   struct stat*const paranoid)),
- screenmailbox Q((char*chp,const gid_t egid,const int Deliverymode));
+ screenmailbox Q((char*chp,const gid_t egid,const int doautoforward));
 
 extern const char maildirnew[];
 extern int accspooldir;
