@@ -10,9 +10,9 @@
  ************************************************************************/
 #ifdef RCS
 static /*const*/char rcsid[]=
- "$Id: formail.c,v 1.102 2001/08/04 07:07:43 guenther Exp $";
+ "$Id$";
 #endif
-static /*const*/char rcsdate[]="$Date: 2001/08/04 07:07:43 $";
+static /*const*/char rcsdate[]="$Date$";
 #include "includes.h"
 #include <ctype.h>		/* iscntrl() */
 #include "formail.h"
@@ -219,7 +219,7 @@ static char*getsender(namep,fldp,headreply)char*namep;struct field*fldp;
   if(i>=0&&(i!=maxindex(sest)||fldp==rdheader))		  /* found anything? */
    { char*saddr;char*tmp;			     /* determine the weight */
      nowm=areply&&headreply?headreply==1?sest[i].wrepl:sest[i].wrrepl:i;chp+=j;
-     tmp=malloc(j=fldp->Tot_len-j);tmemmove(tmp,chp,j);(chp=tmp)[j-1]='\0';
+     tmp=malloc((j=fldp->Tot_len-j) + 1);tmemmove(tmp,chp,j);(chp=tmp)[j-1]='\0';
      if(sest[i].head==From_)
       { char*pastad;
 	if(strchr(saddr=chp,'\n'))		     /* multiple From_ lines */
@@ -418,24 +418,26 @@ int main(lastm,argv)int lastm;const char*const argv[];
 		 goto xusg;
 	      case FM_DUPLICATE:case FM_MINFIELDS:Qnext_arg();chp++;
 	      default:chp--;
-number:		 if(*chp-'0'>(unsigned)9)	    /* the number is not >=0 */
+number:	       { long val;
+		 if(*chp-'0'>(unsigned)9)	    /* the number is not >=0 */
 		    goto usg;
-		 i=strtol(chp,&chp,10);
+		 val=strtol(chp,&chp,10);
 		 switch(lastm)			/* where does the number go? */
-		  { case FM_SKIP:nrskip=i;
+		  { case FM_SKIP:nrskip=val;
 		       break;
-		    case FM_DUPLICATE:maxlen=i;Qnext_arg();
+		    case FM_DUPLICATE:maxlen=val;Qnext_arg();
 		       if(!(idcache=fopen(chp,"r+b"))&&	  /* existing cache? */
 			  !(idcache=fopen(chp,"w+b")))	    /* create cache? */
 			{ nlog("Couldn't open");logqnl(chp);
 			  return EX_CANTCREAT;
 			}
 		       goto nextarg;
-		    case FM_MINFIELDS:minfields=i;
+		    case FM_MINFIELDS:minfields=val;
 		       break;
-		    default:nrtotal=i;
+		    default:nrtotal=val;
 		  }
 		 continue;
+	       }
 	      case FM_BOGUS:bogus=0;
 		 continue;
 	      case FM_BERKELEY:berkeley=1;
@@ -758,9 +760,9 @@ startover:
 	lputssn(buf,buffilled),ctlength-=buffilled,buffilled=lnl=0;
      ;{ int tbl=buflast,lwr='\n';
 	while(--ctlength>=0&&tbl!=EOF)	       /* skip Content-Length: bytes */
-	   lnl=lwr==tbl&&lwr=='\n',putcs(lwr=tbl),tbl=getchar();
+	   lnl=lwr==tbl&&lwr=='\n',lputcs(lwr=tbl),tbl=getchar();
 	if((buflast=tbl)=='\n'&&lwr!=tbl)	/* just before a line break? */
-	   putcs('\n'),buflast=getchar();		/* wrap up loose end */
+	   lputcs('\n'),buflast=getchar();		/* wrap up loose end */
       }
      if(!quiet&&ctlength>0)
       { charNUM(num,ctlength);
@@ -819,7 +821,7 @@ splitit:       { if(!lnl)   /* did the previous mail end with an empty line? */
       { if(split)		       /* gobble up the next start separator */
 	 { buffilled=0;
 #ifdef sMAILBOX_SEPARATOR
-	   getline();buffilled=0;		 /* but only if it's defined */
+	   cgetline();buffilled=0;		 /* but only if it's defined */
 #endif
 	   if(buflast!=EOF)					   /* if any */
 	      goto splitit;
