@@ -6,7 +6,7 @@
  ************************************************************************/
 #ifdef RCS
 static /*const*/char rcsid[]=
- "$Id: formisc.c,v 1.41 2001/06/27 06:41:27 guenther Exp $";
+ "$Id$";
 #endif
 #include "includes.h"
 #include "formail.h"
@@ -66,7 +66,7 @@ inc:	   start++;
 retz:	      *target='\0';
 ret:	      return start;
 	    }
-	   if(*start=='\\')
+	   if(*start=='\\' && *(start + 1))
 	      *target++='\\',start++;
 	   hitspc=2;
 	   goto normal;					      /* normal word */
@@ -83,13 +83,10 @@ normal:	   *target++= *start++;
 	   break;
 	case '"':*target++=delim='"';start++;
       }
-     ;{ int i;
-	do
-	   if((i= *target++= *start++)==delim)	 /* corresponding delimiter? */
-	      break;
-	   else if(i=='\\'&&*start)		    /* skip quoted character */
-	      *target++= *start++;
-	while(*start);						/* anything? */
+     ;{ int i;				   /* search corresponding delimiter */
+        while ((i = *target++ = *start++) && i != delim)
+	   if (i == '\\' && *start)		    /* skip quoted character */
+	      *target++ = *start++;
       }
      hitspc=2;
    }
@@ -105,7 +102,7 @@ void loadsaved(sp)const struct saved*const sp;	     /* load some saved text */
 							    /* append to buf */
 void loadbuf(text,len)const char*const text;const size_t len;
 { if(buffilled+len>buflen)			  /* buf can't hold the text */
-     buf=realloc(buf,buflen+=Bsize);
+     buf=realloc(buf,buflen=buffilled+len+Bsize);
   tmemmove(buf+buffilled,text,len);buffilled+=len;
 }
 
@@ -115,7 +112,7 @@ void loadchar(c)const int c;		      /* append one character to buf */
   buf[buffilled++]=c;
 }
 
-int getline P((void))			   /* read a newline-terminated line */
+int cgetline P((void))			   /* read a newline-terminated line */
 { if(buflast==EOF)			 /* at the end of our Latin already? */
    { loadchar('\n');					  /* fake empty line */
      return EOF;					  /* spread the word */
@@ -183,10 +180,10 @@ void startprog(argv)const char*Const*const argv;
 		 retval=excode;
 	    }					       /* reap some children */
 	while(childlimit&&children>=childlimit||(child=fork())==-1&&children)
-	   for(--children;(excode=waitfor((pid_t)0))!=NO_PROCESS;)
+	   for(--children;(excode=waitfor((pid_t)0))!=NO_PROCESS;--children)
 	    { if(excode!=EXIT_SUCCESS)
 		 retval=excode;
-	      if(--children<=maxchild)
+	      if(children<=maxchild)
 		 break;
 	    }
       }
