@@ -1,12 +1,12 @@
-/*$Id: locking.h,v 1.5 1994/05/26 14:13:03 berg Exp $*/
+/*$Id$*/
 
 void
- lockit P((char*name,char**const lockp)),
- lcllock P((void)),
  unlock P((char**const lockp));
 int
+ lockit P((char*name,char**const lockp)),
+ lcllock P((const char*const noext,const char*const withext)),
  xcreat Q((const char*const name,const mode_t mode,time_t*const tim,
-  const chownit));
+  const int chownit));
 
 #ifdef NOfcntl_lock
 #ifndef USElockf
@@ -21,3 +21,5 @@ int
  fdlock P((int fd)),
  fdunlock P((void));
 #endif
+
+extern char*globlock;
